About
=====

Authors
-------

.. include:: ../AUTHORS

License
-------
``youtubedlapi-server-infusiblecoder`` and its documentation is released to the public domain:

.. literalinclude:: ../LICENSE
    :language: text
